/* Steps to display a 160x144 graphic using 360 GBC tiles

NOTE:  This is adapted from the previous splash.c.  Please read that one first.
	The main difference is that splash.c uses GameMan to reduce the number
   of tiles to less than 256.  This version uses all 360 (20 width x 18 height)
   tiles to produce a full-screen picture.  This version will not work correctly
   on a black and white GameBoy.  It is only for the GameBoy color, because the
   GameBoy Color lets us store twice as many BG tiles.

1) Make a 160x144 (24-bit BMP) graphic (the save-as format will depend on the
		util you choose to use in step 2)
2) Convert the graphic to Tiles with PalRed or GB Color Tiler (www.infinity.nl)
		I would recommend GB Color Tiler for anything intricate (use .TGA)
      Update 1-26-00:
         Peter Havelaar has released a new version of the Color Tiler
	     		See http://www.formula.nl/ie/tool-quantizer.html
3) Make the Map, block filling it with the tiles from step 2 (in GBMB of course)
		File/Map Properties - 20x18 and use the GBR file that you got from step 2
      Design/Block Fill   - 0,0,20,18 with Left2Right, Top2Bottom
      You might want to change the View/Color Set
		Save it.
4) Skip this step.  (Used to be GameMan)
5) Open the optimized Tiles in GBTD and export the tiles to <name>_t.c
		I usually name the label <name>Tiles (ie. splashTiles)
		Include CGB Palette 1 byte (necessary?????)
      Format "GB 4 Color"        (necessary?????)
      Export as one unit
      Split Data with Block Size = 256
      Then, save the Tiles when you're done exporting.
6) Go back into GBMB to export the Map and Attributes
7) Export the map to <name>_m.c with these options
		I usually name the label <name>Map (ie. splashMap)
		1 plane
      Property:  Tile Number (low 8 bits)
8) Export the map to <name>_a.c with these optione
		I usually name the label <name>Pal (ie. splashAttr)
		1 plane
      Property:  GBC BG Attribute

Thanks must go to Harry Mulder for his "WarioCraft" code.  That was a
big help in making this code, and some of his comments are even
included here.

Please feel free to contact me for help or if you have comments on my code.

Ed Mandy
emandy@atcorp.com
ICQ:  17868116
*/


/****************************************************************/
/*              Display a Splash Screen                         */
/****************************************************************/
#include <gb.h>

#include "splash360_t.h"		/*the tiles and palette entries*/
#include "splash360_t.c"

#include "splash360_m.h"		/*the map (pointers to tiles)*/
#include "splash360_m.c"

#include "splash360_a.h"		/*the map's palette entries (pointers to palette)*/
#include "splash360_a.c"      /*these are the GBC BB Attributes.  Palette + bank #*/



/**************************************************************************/
/* GBTD generates a series of constants which contain the various colors  */
/* used by your tileset. These constants will have to be turned into      */
/* an actual palette-table which can be sent to the Gameboy. The          */
/* following array is such a table.                                       */
/**************************************************************************/

UWORD splashPalCGB[] =
{
  splashTilesCGBPal0c0,splashTilesCGBPal0c1,splashTilesCGBPal0c2,splashTilesCGBPal0c3,
  splashTilesCGBPal1c0,splashTilesCGBPal1c1,splashTilesCGBPal1c2,splashTilesCGBPal1c3,
  splashTilesCGBPal2c0,splashTilesCGBPal2c1,splashTilesCGBPal2c2,splashTilesCGBPal2c3,
  splashTilesCGBPal3c0,splashTilesCGBPal3c1,splashTilesCGBPal3c2,splashTilesCGBPal3c3,
  splashTilesCGBPal4c0,splashTilesCGBPal4c1,splashTilesCGBPal4c2,splashTilesCGBPal4c3,
  splashTilesCGBPal5c0,splashTilesCGBPal5c1,splashTilesCGBPal5c2,splashTilesCGBPal5c3,
  splashTilesCGBPal6c0,splashTilesCGBPal6c1,splashTilesCGBPal6c2,splashTilesCGBPal6c3,
  splashTilesCGBPal7c0,splashTilesCGBPal7c1,splashTilesCGBPal7c2,splashTilesCGBPal7c3
};


/***************************************************/
/*                   Main program                  */
/***************************************************/
void main()
{
   int joy;

	DISPLAY_OFF;
	HIDE_BKG;

  /*************************************************************************/
  /* the following set of routines loads the palettes into the display.    */
  /* each palette is send (one by one) by using the command:               */
  /*   set_bkg_palette( palette-no, first color in palette, Palette-data ) */
  /*************************************************************************/

  set_bkg_palette( 7, 1, &splashPalCGB[28] );
  set_bkg_palette( 6, 1, &splashPalCGB[24] );
  set_bkg_palette( 5, 1, &splashPalCGB[20] );
  set_bkg_palette( 4, 1, &splashPalCGB[16] );
  set_bkg_palette( 3, 1, &splashPalCGB[12] );
  set_bkg_palette( 2, 1, &splashPalCGB[8] );
  set_bkg_palette( 1, 1, &splashPalCGB[4] );
  set_bkg_palette( 0, 1, &splashPalCGB[0] );


  /*************************************************************************/
  /* Next, load the tile-data
  /* First, load the first 256 tiles (splashTilesBLK0) into VRAM Bank 0.
  /* Then, load the rest of the tiles (splashTilesBLK1) into VRAM Bank 1.
  /*************************************************************************/
  VBK_REG = 0;//bank 0
  set_bkg_data(0 /* first tile */, 0/*=256*/ /* number of tiles */, splashTilesBLK0 /* label of tiles */);
  VBK_REG = 1;//bank 1
  set_bkg_data(0 /* first tile */, 360-256 /* number of tiles */, splashTilesBLK1 /* label of tiles */);

  /*************************************************************************/
  /* Now it's time to send the map-data to the display. Again, in two      */
  /* steps, as the tiles and attributes reside in different banks.         */
  /* The data is send to the display by using the command:                 */
  /*   set_bkg_tiles( Left, Top, Width, Height, Map-data )                 */
  /*************************************************************************/

  /*************************************************************************/
  /* I think this needs a better explanation.  If you haven't examined
  /*   splash.c, please do.
  /* In the original splash.c, we had less than 256 tiles, so we just used
  /*   the palette data and the Map data.  Well, since we now have more than
  /*   256 tiles, we need to do things differently.
  /*   As you may have noticed, the splashMap needs to point to 360 unique
  /*   tiles.  That means that an 8-bit number won't hold the pointers anymore
  /*   What happens now is that the splashAttr is like the Palette pointer
  /*   (splashPal) and the 9th bit of the splashMap, combined.  Since the
  /*   palette pointer only needs 3 bits, this works just fine.
  /*   Example:  The last Map entry [col 20, row 18] of the map would be
  /*   359, which is 101100111 in binary.  Since we only have 8 bits, we store
  /*   01100111 = 0x67  in splashMap[359]
  /*   If that particulat tile used palette 4, we would have had
  /*   splashPal[359] = 0x04.  Now, since we're using the attributes, instead
  /*   of just the palette entry, we get the 9th bit in bit location 3, so
  /*      splashAttr[359] = splashPal[359] | 0x08
  /*   or splasyAttr[359] = splashPal[359] | (splashMap[359]'s bit 9) << 3
  /*   Simple, huh?
  /*************************************************************************/
  VBK_REG = 1;
  set_bkg_tiles(0,0,splashMapWidth,splashMapHeight,splashAttr);

  VBK_REG = 0;
  set_bkg_tiles(0,0,splashMapWidth,splashMapHeight,splashMap);


  SHOW_BKG;
  DISPLAY_ON;

   do
   {
   	joy = joypad();
   } while (!joy);
	waitpadup();

  	HIDE_BKG;
   DISPLAY_OFF;
}
